rulebase.rules.interval\_based\_operations.basic\_operation module
==================================================================

.. automodule:: rulebase.rules.interval_based_operations.basic_operation
    :members:
    :undoc-members:
    :show-inheritance:
